==> verttice_ui-0.0.20.tar.gz: lib/src/widgets/files/file_full_page_network.dart <==
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_ui/src/const/icons.dart';
import 'package:verttice_ui/src/widgets/files/image_viewer.dart';
import 'package:verttice_ui/src/widgets/files/pdf_viewer_storage.dart';
import 'package:verttice_ui/src/widgets/files/video_viewer_storage.dart';
import 'package:flutter/material.dart';

class FileFullPageNetworkView extends StatefulWidget {
  final FileModel file;
  final String? fileName;

  const FileFullPageNetworkView({
    Key? key,
    required this.file,
    this.fileName,
  }) : super(key: key);

  @override
  State createState() => _FileFullPageNetworkViewState();
}

class _FileFullPageNetworkViewState extends State<FileFullPageNetworkView> {
  late FileModel _file;
  @override
  void initState() {
    super.initState();
    _file = widget.file;
  }

  @override
  void didUpdateWidget(covariant FileFullPageNetworkView oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_file != widget.file) {
      _file = widget.file;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Builder(
      builder: (BuildContext context) {
        if (_file.mimeType.contains("image")) {
          return ImageViewerFullPage(
            url: _file.url,
            imageID: _file.url,
          );
        } else if (_file.mimeType.contains("pdf")) {
          return PdfViewerFullPage(
            url: _file.url,
            fileName: widget.fileName,
          );
        } else if (_file.mimeType.contains("video")) {
          return VideoViewerFullPage(
            url: _file.url,
          );
        }
        return Center(
          child: ThemedIcons.fileUnknow(
            iconStyle: IconStyle(
              color: Colors.amber[600],
              size: 45,
            ),
          ),
        );
      },
    );
  }
}

==> verttice_ui-0.0.47.tar.gz: lib/src/widgets/files/file_full_page_network.dart <==
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_ui/src/const/icons.dart';
import 'package:verttice_ui/src/widgets/files/image_viewer.dart';
import 'package:verttice_ui/src/widgets/files/pdf_viewer_storage.dart';
import 'package:verttice_ui/src/widgets/files/video_viewer_storage.dart';
import 'package:flutter/material.dart';

class FullPageFileViewNetwork extends StatefulWidget {
  final FileModel file;
  final String? fileName;

  const FullPageFileViewNetwork({
    Key? key,
    required this.file,
    this.fileName,
  }) : super(key: key);

  @override
  State createState() => _FullPageFileViewNetworkState();
}

class _FullPageFileViewNetworkState extends State<FullPageFileViewNetwork> {
  late FileModel _file;
  @override
  void initState() {
    super.initState();
    _file = widget.file;
  }

  @override
  void didUpdateWidget(covariant FullPageFileViewNetwork oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_file != widget.file) {
      _file = widget.file;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Builder(
      builder: (BuildContext context) {
        if (_file.mimeType.contains("image")) {
          return ImageViewerFullPage(
            url: _file.url,
            imageID: _file.url,
          );
        } else if (_file.mimeType.contains("pdf")) {
          return PdfViewerFullPage(
            url: _file.url,
            fileName: widget.fileName,
          );
        } else if (_file.mimeType.contains("video")) {
          return VideoViewerFullPage(
            url: _file.url,
          );
        }
        return Center(
          child: ThemedIcons.fileUnknow(
            iconStyle: IconStyle(
              color: Colors.amber[600],
              size: 45,
            ),
          ),
        );
      },
    );
  }
}
